@@ -455,7 +455,8 @@ class YandexParser(object):
 
         if 'z-' in sn.attrib['class'] \
             or 'template-object-badge' in sn.attrib['class']\
-            or 't-construct-adapter__companies' in sn.attrib['class']:
+            or 't-construct-adapter__companies' in sn.attrib['class']\
+            or 'RsyaGuarantee' in sn.attrib['class']:
             #реклама
             return True
 
